@@ -44,7 +44,7 @@ describe 'neutron::agents::ml2::networking_baremetal' do
       should contain_ironic_neutron_agent_config('ironic/auth_type').with_value(p[:auth_type])
       should contain_ironic_neutron_agent_config('ironic/auth_url').with_value(p[:auth_url])
       should contain_ironic_neutron_agent_config('ironic/username').with_value(p[:username])
-      should contain_ironic_neutron_agent_config('ironic/password').with_value(p[:password])
+      should contain_ironic_neutron_agent_config('ironic/password').with_value(p[:password]).with_secret(true)
       should contain_ironic_neutron_agent_config('ironic/project_domain_name').with_value(p[:project_domain_name])
       should contain_ironic_neutron_agent_config('ironic/project_name').with_value(p[:project_name])
       should contain_ironic_neutron_agent_config('ironic/user_domain_name').with_value(p[:user_domain_name])
@@ -54,13 +54,13 @@ describe 'neutron::agents::ml2::networking_baremetal' do
     end
 
     it 'installs ironic-neutron-agent agent package' do
-      should contain_package('python-ironic-neutron-agent').with(
+      should contain_package('python2-ironic-neutron-agent').with(
         :name   => platform_params[:networking_baremetal_agent_package],
         :ensure => p[:package_ensure],
         :tag    => ['openstack', 'neutron-package'],
       )
-      should contain_package('python-ironic-neutron-agent').that_requires('Anchor[neutron::install::begin]')
-      should contain_package('python-ironic-neutron-agent').that_notifies('Anchor[neutron::install::end]')
+      should contain_package('python2-ironic-neutron-agent').that_requires('Anchor[neutron::install::begin]')
+      should contain_package('python2-ironic-neutron-agent').that_notifies('Anchor[neutron::install::end]')
     end
 
     it 'configures networking-baremetal ironic-neutron-agent service' do
@@ -101,18 +101,8 @@ describe 'neutron::agents::ml2::networking_baremetal' do
       let (:platform_params) do
         case facts[:osfamily]
         when 'RedHat'
-          if facts[:operatingsystem] == 'Fedora'
-            { :networking_baremetal_agent_package => 'python3-ironic-neutron-agent',
-              :networking_baremetal_agent_service => 'ironic-neutron-agent' }
-          else
-            if facts[:operatingsystemmajrelease] > '7'
-              { :networking_baremetal_agent_package => 'python3-ironic-neutron-agent',
-                :networking_baremetal_agent_service => 'ironic-neutron-agent' }
-            else
-              { :networking_baremetal_agent_package => 'python-ironic-neutron-agent',
-                :networking_baremetal_agent_service => 'ironic-neutron-agent' }
-            end
-          end
+          { :networking_baremetal_agent_package => 'python2-ironic-neutron-agent',
+            :networking_baremetal_agent_service => 'ironic-neutron-agent' }
         end
       end
       case facts[:osfamily]
