@@ -135,14 +135,19 @@ describe 'neutron::agents::ml2::sriov' do
       end
     end
 
-    context 'when resource_provider_bandwidths is set' do
+    context 'when parameters for resource providers are set' do
       before :each do
-        params.merge!(:resource_provider_bandwidths => ['provider-a', 'provider-b'])
+        params.merge!(
+          :resource_provider_bandwidths  => ['provider-a', 'provider-b'],
+          :resource_provider_hypervisors => ['provider-a:compute-a', 'provider-b:compute-b'],
+        )
       end
 
-      it 'configures resource_provider_bandwidths' do
+      it 'configures resource providers' do
         should contain_neutron_sriov_agent_config('sriov_nic/resource_provider_bandwidths').\
           with_value('provider-a,provider-b')
+        should contain_neutron_sriov_agent_config('sriov_nic/resource_provider_hypervisors').\
+          with_value('provider-a:compute-a,provider-b:compute-b')
       end
     end
   end
